Welcome to ClientVPS Mirrors

Help for package IRTShiny
Type: Package
Title: Item Response Theory via Shiny
Version: 1.2
Date: 2017-04-07
Author: W. Kyle Hamilton <kyle.hamilton@gmail.com>, Atsushi Mizumoto <atsushi@mizumot.com>
Maintainer: W. Kyle Hamilton <kyle.hamilton@gmail.com>
Description: Interactive shiny application for running Item Response Theory analysis. Provides graphics for characteristic and information curves.
License: GPL-3
Depends: R (≥ 3.0.3)
Imports: shiny, shinyAce, beeswarm, CTT, ltm, parallel, psych
LazyData: true
NeedsCompilation: no
Packaged: 2017-04-07 22:25:26 UTC; hcilab
Repository: CRAN
Date/Publication: 2017-04-07 22:31:05 UTC

This function will start IRTShiny

Description

An interactive Shiny application for running a IRT analysis.

Usage

startIRT()

Details

Start IRTShiny

This starts the Shiny application IRT.

Value

Nothing

Examples

## Not run: 
library(shiny)
startIRT()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.